@@ -99,6 +99,9 @@ func (c *ProjectInspectCommand) FormatProject(projectTarget string) error {
 		workspaceNames = append(workspaceNames, ws.Workspace.Workspace)
 	}
 
+	var datasourcePollEnabled bool
+	var datasourcePollInterval string
+
 	var gitUrl, gitRef, gitPath, remoteDesc string
 	dataSource := "Local" // if unset, assume local
 	if project.DataSource != nil {
@@ -114,11 +117,19 @@ func (c *ProjectInspectCommand) FormatProject(projectTarget string) error {
 		case *pb.Job_DataSource_Remote:
 			dataSource = "Remote"
 			remoteDesc = ds.Remote.Description
+
+			if ds.Remote.GitRemote != nil {
+				gitRef = ds.Remote.GitRemote.Ref
+				gitPath = ds.Remote.GitRemote.Path
+
+				if ds.Remote.DeployOnChange {
+					datasourcePollEnabled = true
+					datasourcePollInterval = "automatic"
+				}
+			}
 		}
 	}
 
-	var datasourcePollEnabled bool
-	var datasourcePollInterval string
 	if project.DataSourcePoll != nil {
 		datasourcePollEnabled = project.DataSourcePoll.Enabled
 		datasourcePollInterval = project.DataSourcePoll.Interval
