@@ -15,6 +15,7 @@ import (
 )
 
 func TestInstanceExecCreateByTargetedInstance_disabled(t *testing.T) {
+	ctx := context.Background()
 	require := require.New(t)
 
 	s := TestState(t)
@@ -23,25 +24,26 @@ func TestInstanceExecCreateByTargetedInstance_disabled(t *testing.T) {
 	// Create an instance
 	instance := testInstance(t, nil)
 	instance.DisableExec = true
-	require.NoError(s.InstanceCreate(instance))
+	require.NoError(s.InstanceCreate(ctx, instance))
 
 	{
 		// Create an instance exec targetting the specific instance
 		rec := &serverstate.InstanceExec{
 			InstanceId: instance.Id,
 		}
-		err := s.InstanceExecCreateByTargetedInstance(instance.Id, rec)
+		err := s.InstanceExecCreateByTargetedInstance(ctx, instance.Id, rec)
 		require.Error(err)
 		require.Equal(codes.PermissionDenied, status.Code(err))
 	}
 
 	// List them
-	list, err := s.InstanceExecListByInstanceId(instance.Id, nil)
+	list, err := s.InstanceExecListByInstanceId(ctx, instance.Id, nil)
 	require.NoError(err)
 	require.Len(list, 0)
 }
 
 func TestInstanceExecCreateByDeploymentId_invalidDeployment(t *testing.T) {
+	ctx := context.Background()
 	require := require.New(t)
 
 	s := TestState(t)
@@ -49,12 +51,13 @@ func TestInstanceExecCreateByDeploymentId_invalidDeployment(t *testing.T) {
 
 	// Create an instance
 	rec := &serverstate.InstanceExec{}
-	err := s.InstanceExecCreateByDeployment("nope", rec)
+	err := s.InstanceExecCreateByDeployment(ctx, "nope", rec)
 	require.Error(err)
 	require.Equal(codes.ResourceExhausted, status.Code(err))
 }
 
 func TestInstanceExecCreateByDeploymentId_allDisabled(t *testing.T) {
+	ctx := context.Background()
 	require := require.New(t)
 
 	s := TestState(t)
@@ -63,23 +66,24 @@ func TestInstanceExecCreateByDeploymentId_allDisabled(t *testing.T) {
 	// Create an instance
 	instance := testInstance(t, nil)
 	instance.DisableExec = true
-	require.NoError(s.InstanceCreate(instance))
+	require.NoError(s.InstanceCreate(ctx, instance))
 
 	{
 		// Create an instance exec targetting the specific instance
 		rec := &serverstate.InstanceExec{}
-		err := s.InstanceExecCreateByDeployment(instance.DeploymentId, rec)
+		err := s.InstanceExecCreateByDeployment(ctx, instance.DeploymentId, rec)
 		require.Error(err)
 		require.Equal(codes.ResourceExhausted, status.Code(err))
 	}
 
 	// List them
-	list, err := s.InstanceExecListByInstanceId(instance.Id, nil)
+	list, err := s.InstanceExecListByInstanceId(ctx, instance.Id, nil)
 	require.NoError(err)
 	require.Len(list, 0)
 }
 
 func TestInstanceExecCreateByDeploymentId_valid(t *testing.T) {
+	ctx := context.Background()
 	require := require.New(t)
 
 	s := TestState(t)
@@ -87,24 +91,24 @@ func TestInstanceExecCreateByDeploymentId_valid(t *testing.T) {
 
 	// Create an instance
 	instance := testInstance(t, nil)
-	require.NoError(s.InstanceCreate(instance))
+	require.NoError(s.InstanceCreate(ctx, instance))
 
 	{
 		// Create an instance exec
 		rec := &serverstate.InstanceExec{}
-		require.NoError(s.InstanceExecCreateByDeployment(instance.DeploymentId, rec))
+		require.NoError(s.InstanceExecCreateByDeployment(ctx, instance.DeploymentId, rec))
 		require.NotEmpty(rec.Id)
 		require.Equal(instance.Id, rec.InstanceId)
 
 		// Test single get
-		found, err := s.InstanceExecById(rec.Id)
+		found, err := s.InstanceExecById(ctx, rec.Id)
 		require.NoError(err)
 		require.Equal(rec, found)
 	}
 
 	// List them
 	ws := memdb.NewWatchSet()
-	list, err := s.InstanceExecListByInstanceId(instance.Id, ws)
+	list, err := s.InstanceExecListByInstanceId(ctx, instance.Id, ws)
 	require.NoError(err)
 	require.Len(list, 1)
 	require.True(ws.Watch(time.After(50 * time.Millisecond)))
@@ -112,7 +116,7 @@ func TestInstanceExecCreateByDeploymentId_valid(t *testing.T) {
 	{
 		// Next one shuld get the same instance since its all we have
 		rec := &serverstate.InstanceExec{}
-		require.NoError(s.InstanceExecCreateByDeployment(instance.DeploymentId, rec))
+		require.NoError(s.InstanceExecCreateByDeployment(ctx, instance.DeploymentId, rec))
 		require.NotEmpty(rec.Id)
 		require.Equal(instance.Id, rec.InstanceId)
 
@@ -120,39 +124,39 @@ func TestInstanceExecCreateByDeploymentId_valid(t *testing.T) {
 		require.False(ws.Watch(time.After(50 * time.Millisecond)))
 	}
 
-	list, err = s.InstanceExecListByInstanceId(instance.Id, nil)
+	list, err = s.InstanceExecListByInstanceId(ctx, instance.Id, nil)
 	require.NoError(err)
 	require.Len(list, 2)
 
 	// Create another instance
 	instance = testInstance(t, &serverstate.Instance{Id: "B", DeploymentId: "A"})
-	require.NoError(s.InstanceCreate(instance))
+	require.NoError(s.InstanceCreate(ctx, instance))
 
 	{
 		// Next one shuld get the B because its less loaded
 		rec := &serverstate.InstanceExec{}
-		require.NoError(s.InstanceExecCreateByDeployment(instance.DeploymentId, rec))
+		require.NoError(s.InstanceExecCreateByDeployment(ctx, instance.DeploymentId, rec))
 		require.NotEmpty(rec.Id)
 		require.Equal(instance.Id, rec.InstanceId)
 
 		// Should be able to delete
-		require.NoError(s.InstanceExecDelete(rec.Id))
+		require.NoError(s.InstanceExecDelete(ctx, rec.Id))
 	}
 
 	// Create another instance, with exec disabled
 	{
 		instance := testInstance(t, &serverstate.Instance{
 			Id: "C", DeploymentId: "A", DisableExec: true})
-		require.NoError(s.InstanceCreate(instance))
+		require.NoError(s.InstanceCreate(ctx, instance))
 
 		// Should not get C
 		rec := &serverstate.InstanceExec{}
-		require.NoError(s.InstanceExecCreateByDeployment(instance.DeploymentId, rec))
+		require.NoError(s.InstanceExecCreateByDeployment(ctx, instance.DeploymentId, rec))
 		require.NotEmpty(rec.Id)
 		require.NotEqual("C", rec.InstanceId)
 
 		// Should be able to delete
-		require.NoError(s.InstanceExecDelete(rec.Id))
+		require.NoError(s.InstanceExecDelete(ctx, rec.Id))
 	}
 
 	{
@@ -160,18 +164,19 @@ func TestInstanceExecCreateByDeploymentId_valid(t *testing.T) {
 		rec := &serverstate.InstanceExec{
 			InstanceId: instance.Id,
 		}
-		require.NoError(s.InstanceExecCreateByTargetedInstance(instance.Id, rec))
+		require.NoError(s.InstanceExecCreateByTargetedInstance(ctx, instance.Id, rec))
 		require.NotEmpty(rec.Id)
 		require.Equal(instance.Id, rec.InstanceId)
 
 		// Test single get
-		found, err := s.InstanceExecById(rec.Id)
+		found, err := s.InstanceExecById(ctx, rec.Id)
 		require.NoError(err)
 		require.Equal(rec, found)
 	}
 }
 
 func TestInstanceExecCreateByDeploymentId_longrunningonly(t *testing.T) {
+	ctx := context.Background()
 	require := require.New(t)
 
 	s := TestState(t)
@@ -179,30 +184,30 @@ func TestInstanceExecCreateByDeploymentId_longrunningonly(t *testing.T) {
 
 	// Create an instance
 	instance := testInstance(t, nil)
-	require.NoError(s.InstanceCreate(instance))
+	require.NoError(s.InstanceCreate(ctx, instance))
 
 	// Create a ondemand instance
 	od := testInstance(t, nil)
 	od.Id = "A2"
 	od.Type = gen.Instance_ON_DEMAND
-	require.NoError(s.InstanceCreate(od))
+	require.NoError(s.InstanceCreate(ctx, od))
 
 	// Create a virtual instance
 	virt := testInstance(t, nil)
 	virt.Id = "A3"
 	virt.Type = gen.Instance_VIRTUAL
-	require.NoError(s.InstanceCreate(virt))
+	require.NoError(s.InstanceCreate(ctx, virt))
 
 	// We'll create 3 instance exec and make sure they all go to instance only
 	for i := 0; i < 3; i++ {
 		// Create an instance exec
 		rec := &serverstate.InstanceExec{}
-		require.NoError(s.InstanceExecCreateByDeployment(instance.DeploymentId, rec))
+		require.NoError(s.InstanceExecCreateByDeployment(ctx, instance.DeploymentId, rec))
 		require.NotEmpty(rec.Id)
 		require.Equal(instance.Id, rec.InstanceId)
 
 		// Test single get
-		found, err := s.InstanceExecById(rec.Id)
+		found, err := s.InstanceExecById(ctx, rec.Id)
 		require.NoError(err)
 		require.Equal(rec, found)
 	}
@@ -224,7 +229,7 @@ func TestInstanceExecCreateForVirtualInstance(t *testing.T) {
 		instance := testInstance(t, nil)
 		instance.Id = instId
 
-		require.NoError(s.InstanceCreate(instance))
+		require.NoError(s.InstanceCreate(ctx, instance))
 	}()
 
 	{
@@ -235,14 +240,14 @@ func TestInstanceExecCreateForVirtualInstance(t *testing.T) {
 		require.Equal(instId, rec.InstanceId)
 
 		// Test single get
-		found, err := s.InstanceExecById(rec.Id)
+		found, err := s.InstanceExecById(ctx, rec.Id)
 		require.NoError(err)
 		require.Equal(rec, found)
 	}
 
 	// List them
 	ws := memdb.NewWatchSet()
-	list, err := s.InstanceExecListByInstanceId(instId, ws)
+	list, err := s.InstanceExecListByInstanceId(ctx, instId, ws)
 	require.NoError(err)
 	require.Len(list, 1)
 	require.True(ws.Watch(time.After(50 * time.Millisecond)))
