@@ -1,6 +1,7 @@
 package boltdbstate
 
 import (
+	"context"
 	bolt "go.etcd.io/bbolt"
 )
 
@@ -9,14 +10,14 @@ var (
 )
 
 // ServerIdSet writes the server ID.
-func (s *State) ServerIdSet(id string) error {
+func (s *State) ServerIdSet(ctx context.Context, id string) error {
 	return s.db.Update(func(dbTxn *bolt.Tx) error {
 		return dbTxn.Bucket(serverConfigBucket).Put(serverIdKey, []byte(id))
 	})
 }
 
 // ServerIdGet gets the server ID.
-func (s *State) ServerIdGet() (string, error) {
+func (s *State) ServerIdGet(ctx context.Context) (string, error) {
 	var result string
 	err := s.db.View(func(dbTxn *bolt.Tx) error {
 		result = string(dbTxn.Bucket(serverConfigBucket).Get(serverIdKey))
