@@ -46,12 +46,13 @@ type nomadConfig struct {
 	serviceBackendTags []string `hcl:"service_backend_tags:optional"`
 	serviceAddress     string   `hcl:"service_address,optional"`
 	networkMode        string   `hcl:"network_mode,optional"`
+	hostNetwork        string   `hcl:"host_network,optional"`
 
 	consulService            bool     `hcl:"consul_service,optional"`
 	consulServiceUITags      []string `hcl:"consul_service_ui_tags:optional"`
 	consulServiceBackendTags []string `hcl:"consul_service_backend_tags:optional"`
 	consulDatacenter         string   `hcl:"consul_datacenter,optional"`
-	consulDomain             string   `hcl:"consul_datacenter,optional"`
+	consulDomain             string   `hcl:"consul_domain,optional"`
 	consulToken              string   `hcl:"consul_token,optional"`
 
 	// If set along with consul, will use this hostname instead of
@@ -60,7 +61,7 @@ type nomadConfig struct {
 
 	odrImage string `hcl:"odr_image,optional"`
 
-	region         string   `hcl:"namespace,optional"`
+	region         string   `hcl:"region,optional"`
 	datacenters    []string `hcl:"datacenters,optional"`
 	policyOverride bool     `hcl:"policy_override,optional"`
 
@@ -905,20 +906,27 @@ func waypointNomadJob(c nomadConfig, rawRunFlags []string, upgrade bool) *api.Jo
 	}
 	tg.Services = services
 
+	hostNetwork := "default"
+	if c.hostNetwork != "" {
+		hostNetwork = c.hostNetwork
+	}
+
 	tg.Networks = []*api.NetworkResource{
 		{
 			Mode: c.networkMode,
 			// currently set to static; when ui command can be dynamic - update this
 			ReservedPorts: []api.Port{
 				{
-					Label: "ui",
-					Value: httpPort,
-					To:    httpPort,
+					Label:       "ui",
+					Value:       httpPort,
+					To:          httpPort,
+					HostNetwork: hostNetwork,
 				},
 				{
-					Label: "server",
-					To:    grpcPort,
-					Value: grpcPort,
+					Label:       "server",
+					To:          grpcPort,
+					Value:       grpcPort,
+					HostNetwork: hostNetwork,
 				},
 			},
 		},
@@ -1175,6 +1183,14 @@ func (i *NomadInstaller) InstallFlags(set *flag.Set) {
 		Default: "host",
 	})
 
+	set.StringVar(&flag.StringVar{
+		Name:   "nomad-host-network",
+		Target: &i.config.hostNetwork,
+		Usage: "Designates the host network name to use when allocating the" +
+			" ports of the Waypoint server.",
+		Default: "default",
+	})
+
 	set.StringVar(&flag.StringVar{
 		Name:   "nomad-odr-image",
 		Target: &i.config.odrImage,
@@ -1463,6 +1479,14 @@ func (i *NomadInstaller) UpgradeFlags(set *flag.Set) {
 		Default: "host",
 	})
 
+	set.StringVar(&flag.StringVar{
+		Name:   "nomad-host-network",
+		Target: &i.config.hostNetwork,
+		Usage: "Designates the host network name to use when allocating the" +
+			" ports of the Waypoint server.",
+		Default: "default",
+	})
+
 	set.StringVar(&flag.StringVar{
 		Name:   "nomad-odr-image",
 		Target: &i.config.odrImage,
