@@ -17,6 +17,7 @@ import (
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/pkg/server"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	serverptypes "github.com/hashicorp/waypoint/pkg/server/ptypes"
 	"github.com/hashicorp/waypoint/pkg/serverconfig"
 	"github.com/hashicorp/waypoint/pkg/serverstate"
@@ -26,9 +27,15 @@ func (s *Service) GetJob(
 	ctx context.Context,
 	req *pb.GetJobRequest,
 ) (*pb.Job, error) {
-	job, err := s.state(ctx).JobById(req.JobId, nil)
+	job, err := s.state(ctx).JobById(ctx, req.JobId, nil)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get job by id",
+			"job_id",
+			req.JobId,
+		)
 	}
 	if job == nil || job.Job == nil {
 		return nil, status.Errorf(codes.NotFound, "job not found")
@@ -41,13 +48,22 @@ func (s *Service) ListJobs(
 	ctx context.Context,
 	req *pb.ListJobsRequest,
 ) (*pb.ListJobsResponse, error) {
-	jobs, err := s.state(ctx).JobList(req)
-	if err != nil {
+	if err := serverptypes.ValidateListJobsRequest(req); err != nil {
 		return nil, err
 	}
 
+	jobs, pagination, err := s.state(ctx).JobList(ctx, req)
+	if err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error listing jobs",
+		)
+	}
+
 	return &pb.ListJobsResponse{
-		Jobs: jobs,
+		Jobs:       jobs,
+		Pagination: pagination,
 	}, nil
 }
 
@@ -55,8 +71,14 @@ func (s *Service) CancelJob(
 	ctx context.Context,
 	req *pb.CancelJobRequest,
 ) (*empty.Empty, error) {
-	if err := s.state(ctx).JobCancel(req.JobId, req.Force); err != nil {
-		return nil, err
+	if err := s.state(ctx).JobCancel(ctx, req.JobId, req.Force); err != nil {
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error cancelling job",
+			"job_id",
+			req.JobId,
+		)
 	}
 
 	return &empty.Empty{}, nil
@@ -83,7 +105,7 @@ func (s *Service) queueJobMulti(
 	}
 
 	// Queue the jobs
-	if err := s.state(ctx).JobCreate(jobQueue...); err != nil {
+	if err := s.state(ctx).JobCreate(ctx, jobQueue...); err != nil {
 		return nil, err
 	}
 
@@ -111,23 +133,21 @@ func (s *Service) queueJobReqToJob(
 
 	// Verify the project exists and use that to set the default data source
 	log.Debug("checking job project", "project", job.Application.Project)
-	project, err := s.state(ctx).ProjectGet(&pb.Ref_Project{Project: job.Application.Project})
+	project, err := s.state(ctx).ProjectGet(ctx, &pb.Ref_Project{Project: job.Application.Project})
 	if status.Code(err) == codes.NotFound {
-		return nil, "", status.Errorf(codes.NotFound,
+		return nil, "", hcerr.UserErrorWithCodef(codes.NotFound, err,
 			"Project %q was not found! Please ensure that 'waypoint init' was run with this project.",
-			job.Application.Project,
-		)
+			job.Application.Project)
 	}
 
 	if job.DataSource == nil {
 		if project.DataSource == nil {
-			return nil, "", status.Errorf(codes.FailedPrecondition,
+			return nil, "", hcerr.UserConditionWithCodef(codes.FailedPrecondition,
 				"Project %s does not have a data source configured. Remote jobs "+
 					"require a data source such as Git to be configured with the project. "+
 					"Data sources can be configured via the CLI or UI. For help, see : "+
 					"https://www.waypointproject.io/docs/projects/git#configuring-the-project",
-				job.Application.Project,
-			)
+				job.Application.Project)
 		}
 
 		job.DataSource = project.DataSource
@@ -139,7 +159,7 @@ func (s *Service) queueJobReqToJob(
 			job, err = s.populateDataSource(ctx, job)
 			if err != nil {
 				log.Error("error populating data source for job", "error", err)
-				return nil, "", status.Errorf(codes.Internal,
+				return nil, "", hcerr.UserErrorWithCodef(codes.Internal, err,
 					"An internal server issue was detected when calculating the data source")
 			}
 
@@ -147,14 +167,14 @@ func (s *Service) queueJobReqToJob(
 			// error out.
 			if job.DataSource.GetRemote() != nil {
 				log.Error("populateDataSource returned another remote DS job")
-				return nil, "", status.Errorf(codes.Internal,
+				return nil, "", hcerr.UserConditionWithCodef(codes.Internal,
 					"An internal server issue was detected when calculating the data source")
 			}
 		} else {
-			log.Error("job has a remote DataSource but server provided to populateDataSource")
+			log.Error("job has a remote DataSource but server provided no populateDataSource")
 			// This is a server misconfiguration.
 			if job.DataSource.GetRemote() != nil {
-				return nil, "", status.Errorf(codes.Internal,
+				return nil, "", hcerr.UserConditionWithCodef(codes.Internal,
 					"An internal server issue was detected when calculating the data source")
 			}
 		}
@@ -164,7 +184,8 @@ func (s *Service) queueJobReqToJob(
 	if job.Id == "" {
 		id, err := server.Id()
 		if err != nil {
-			return nil, "", status.Errorf(codes.Internal, "uuid generation failed: %s", err)
+			return nil, "", hcerr.UserErrorWithCodef(codes.Internal, err,
+				"uuid generation failed")
 		}
 		job.Id = id
 	}
@@ -174,8 +195,8 @@ func (s *Service) queueJobReqToJob(
 	if req.ExpiresIn != "" {
 		dur, err := time.ParseDuration(req.ExpiresIn)
 		if err != nil {
-			return nil, "", status.Errorf(codes.FailedPrecondition,
-				"Invalid expiry duration: %s", err.Error())
+			return nil, "", hcerr.UserErrorWithCodef(codes.FailedPrecondition, err,
+				"Invalid job expiry duration %q: %q", req.ExpiresIn, err.Error())
 		}
 		job.ExpireTime = timestamppb.New(time.Now().Add(dur))
 	}
@@ -184,7 +205,7 @@ func (s *Service) queueJobReqToJob(
 	// Use a default ODR profile if it doesn't already have one assigned.
 	if _, ok := job.TargetRunner.Target.(*pb.Ref_Runner_Any); ok {
 		if job.OndemandRunner == nil {
-			ods, err := s.state(ctx).OnDemandRunnerConfigDefault()
+			ods, err := s.state(ctx).OnDemandRunnerConfigDefault(ctx)
 			if err != nil {
 				return nil, "", err
 			}
@@ -232,6 +253,8 @@ func (s *Service) QueueJob(
 	ctx context.Context,
 	req *pb.QueueJobRequest,
 ) (*pb.QueueJobResponse, error) {
+	log := hclog.FromContext(ctx)
+
 	if req.Job == nil {
 		return nil, status.Errorf(codes.FailedPrecondition, "job must be set")
 	}
@@ -247,12 +270,12 @@ func (s *Service) QueueJob(
 
 	jobs, jobId, err := s.queueJobReqToJob(ctx, req)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(log, err, "failed to create job to queue")
 	}
 
 	// Queue the job
-	if err := s.state(ctx).JobCreate(jobs...); err != nil {
-		return nil, err
+	if err := s.state(ctx).JobCreate(ctx, jobs...); err != nil {
+		return nil, hcerr.Externalize(log, err, "failed to create job(s)")
 	}
 
 	return &pb.QueueJobResponse{JobId: jobId}, nil
@@ -296,7 +319,7 @@ func (s *Service) wrapJobWithRunner(
 	source *pb.Job,
 ) ([]*pb.Job, error) {
 	// Get the runner profile we're going to use for this runner.
-	od, err := s.state(ctx).OnDemandRunnerConfigGet(source.OndemandRunner)
+	od, err := s.state(ctx).OnDemandRunnerConfigGet(ctx, source.OndemandRunner)
 	if err != nil {
 		return nil, err
 	}
@@ -369,10 +392,10 @@ func (s *Service) wrapJobWithRunner(
 		// If we're skipping, the primary task job becomes the watch.
 		task.TaskJob = &pb.Ref_Job{Id: watchJob.Id}
 	}
-	if err := s.state(ctx).TaskPut(task); err != nil {
+	if err := s.state(ctx).TaskPut(ctx, task); err != nil {
 		return nil, err
 	} else {
-		task, err := s.state(ctx).TaskGet(&pb.Ref_Task{
+		task, err := s.state(ctx).TaskGet(ctx, &pb.Ref_Task{
 			Ref: &pb.Ref_Task_JobId{
 				JobId: sourceJob.Id,
 			},
@@ -668,9 +691,9 @@ func (s *Service) GetJobStream(
 
 	// Get the job
 	ws := memdb.NewWatchSet()
-	job, err := s.state(ctx).JobById(req.JobId, ws)
+	job, err := s.state(ctx).JobById(ctx, req.JobId, ws)
 	if err != nil {
-		return err
+		return hcerr.Externalize(log, err, "failed to get job with id", "job_id", req.JobId)
 	}
 	if job == nil {
 		return status.Errorf(codes.NotFound, "job not found for ID: %s", req.JobId)
@@ -683,7 +706,7 @@ func (s *Service) GetJobStream(
 			Open: &pb.GetJobStreamResponse_Open{},
 		},
 	}); err != nil {
-		return err
+		return hcerr.Externalize(log, err, "failed to send job response")
 	}
 
 	// Start a goroutine that watches for job changes
@@ -709,7 +732,7 @@ func (s *Service) GetJobStream(
 
 			// Updated job, requery it
 			ws = memdb.NewWatchSet()
-			job, err = s.state(ctx).JobById(job.Id, ws)
+			job, err = s.state(ctx).JobById(ctx, job.Id, ws)
 			if err != nil {
 				log.Error("error acquiring job by id", "error", err, "id", req.JobId)
 				errCh <- err
