@@ -73,10 +73,12 @@ type Interface interface {
 	// Config (App, Runner, etc.)
 
 	ConfigSet(context.Context, ...*pb.ConfigVar) error
+	ConfigDelete(context.Context, ...*pb.ConfigVar) error
 	ConfigGet(context.Context, *pb.ConfigGetRequest) ([]*pb.ConfigVar, error)
 	ConfigGetWatch(context.Context, *pb.ConfigGetRequest, memdb.WatchSet) ([]*pb.ConfigVar, error)
 
 	ConfigSourceSet(context.Context, ...*pb.ConfigSource) error
+	ConfigSourceDelete(context.Context, ...*pb.ConfigSource) error
 	ConfigSourceGet(context.Context, *pb.GetConfigSourceRequest) ([]*pb.ConfigSource, error)
 	ConfigSourceGetWatch(context.Context, *pb.GetConfigSourceRequest, memdb.WatchSet) ([]*pb.ConfigSource, error)
 
