@@ -12,7 +12,7 @@ export default Factory.extend({
 
   random: trait({
     state: () => randomStateName(),
-
+    details: 'Example status details',
     completeTime: () => faker.date.recent(),
   }),
 
@@ -20,6 +20,10 @@ export default Factory.extend({
     state: 'SUCCESS',
   }),
 
+  error: trait({
+    state: 'ERROR',
+  }),
+
   'seconds-old': trait({
     completeTime: () => new Date(),
   }),
